<?php
// $Id$

/**
 * @file
 * OM Maximenu Admin Utilities
 *
 * @author: Daniel Honrade http://drupal.org/user/351112
 *
 */
 
/**
 * Load all OM Maximenu blocks
 * 
 * This will process all created OM Maximenu blocks
 *
 */
function om_maximenu_load($maximenu_delta = '') {
  static $once = 0;
  $maximenu_delta = explode('-', $maximenu_delta);
  //$maximenu_delta = 'om-maximenu-1';
  $delta = $maximenu_delta[2];
  if ($delta != 0) {
    $maximenus = variable_get('om_maximenu', '');
    $skin = $maximenus[$delta]['skin'];
    $fade = $maximenus[$delta]['fade'];    
    $maximenus[$delta]['skin'] = $skin;
    $maximenu_name = strtolower(preg_replace('/ /', '-', $maximenus[$delta]['title']));      
    drupal_add_css(drupal_get_path('module', 'om_maximenu') . '/skin/' . $skin . '/' . $skin . '.css');
    om_maximenu_hover_js($fade, 'om-maximenu-' . $maximenu_name);
    $out = array();
    $out['title'] = $maximenus[$delta]['title'];
    $out['content'] = om_maximenu_links_render($maximenus[$delta]);
    $once++;
    return $out;
  }
}


/**
 * OM Maximenu links rendering engine
 *
 */
function om_maximenu_links_render($links = array()) {
  $count = 0;
  $total = count($links);
  $skin = preg_replace('/_/', '-', $links['skin']);
  $maximenu_name = strtolower(preg_replace('/ /', '-', $links['title']));      
  $out = '<div class="om-maximenu om-maximenu-' . $skin . ' om-maximenu-' . $maximenu_name . '">';
  $out .= '<ul class="om-menu">';  
  usort($links['links'], 'om_sort_by_weight'); 
  $attributes = array();
  foreach ($links['links'] as $key => $content) {
    $count++;
    //dsm($content);
    $class_id = preg_replace('/ /', '-', strtolower($content['link_title']));
    // li classes
    ($count == 1) ? $classes = ' first': $classes = '';
    if ($count == $total) $classes .= ' last';  
    $classes .= ' leaf-' . $class_id;     
    if ($_GET['q'] == $content['path']) $classes .= ' active'; 
    if (empty($content['path']) && drupal_is_front_page()) {
      $classes .= ' active'; 
      $content['class'] .= ' active'; 
    }          
    // link attributes
    if (!empty($content['id'])) $attributes['attributes']['id']    = $content['id'];
    $attributes['attributes']['class'] = !empty($content['class']) ?  'om-link ' . $content['class']: 'om-link link-' . $class_id;
    if (!empty($content['description'])) $attributes['attributes']['title'] = $content['description'];     
    
    $out .= '<li id="om-leaf-' . $key . '" class="om-leaf' . $classes . '">';    
    $out .= l($content['link_title'], $content['path'], $attributes);
    $out .= om_maximenu_content_render($content['content']);    
    $out .= '</li>';
  }
  $out .= '</ul>';  
  $out .= '<div class="om-maximenu-edit"><a href="' . base_path() . 'admin/settings/om-maximenu?destination=' . $_GET['q']. '">Edit Maximenu</a></div>';    
  $out .= '</div>';  
  return $out;
}


/**
 * OM Maximenu content rendering engine
 *
 */
function om_maximenu_content_render($content = '') {

  if (!empty($content)) {
    // enclose the content with divs for efficient image border theming
    $out = '<div class="om-maximenu-content om-maximenu-content-nofade">';
    $out .= '<div class="om-maximenu-top"><div class="om-maximenu-top-left"></div><div class="om-maximenu-top-right"></div></div>';
    $out .= '<div class="om-maximenu-middle"><div class="om-maximenu-middle-left"><div class="om-maximenu-middle-right">';      
    $count = 0;
    usort($content, 'om_sort_by_weight');  
    foreach ($content as $key => $prop) {
        $count++;
        ($count == 1) ? $classes = ' first': $classes = '';
        if ($count == $total) $classes .= ' last';       
        $block = module_invoke($prop['module'], 'block', 'view', $prop['delta']); 
        $out .= '<div class="block block-' . $prop['module'] . ' block-' . $prop['module'] . '-id-' . $prop['delta'] . $classes . '">';            
        $out .= ($prop['title'] != '<none>') ? '<h3 class="title">' . $prop['title'] . '</h3>': ''; 
        $out .= $block['content']; 
        $out .= '</div>';            
    }
    $out .= '<div class="clearfix"></div></div></div></div>';      
    $out .= '<div class="om-maximenu-bottom"><div class="om-maximenu-bottom-left"></div><div class="om-maximenu-bottom-right"></div></div>';    
    $out .= '<div class="om-maximenu-arrow"></div>';    
    $out .= '</div>'; 
    return $out;
  } 
}

/**
 * Sorting by weight
 *
 */
function om_sort_by_weight($a, $b) {
  return $a['weight'] - $b['weight'];
}


/**
 * OM Maximenu get styles from /skin directory
 * - reads directory names
 */
function om_maximenu_style_get() {
  $files = array();
  $dir = drupal_get_path('module', 'om_maximenu') . '/skin/';
  $folders = scandir($dir);
  $excluded_files = array('.', '..', '.cvs', '.svn', '.git');

  foreach ($folders as $key => $val) {
		if (!in_array($val, $excluded_files)) (is_dir($dir . $val)) ? $files[$val] = ucwords(preg_replace('/_/', ' ', $val)): '';     
  }
  return $files;
}


/**
 * Hover delay using hoverintent jquery plugin
 *
 */
function om_maximenu_hover_js($checked = 0, $menu = 'om-maximenu') {
  
  $add_js = "
    $(document).ready(function(){
      $('." . $menu . " li.om-leaf .om-maximenu-content').removeClass('om-maximenu-content-nofade');
      //$('." . $menu . " li.om-leaf').hover(omFadeIn,omFadeOut); //native jquery
      //$('." . $menu . " li.om-leaf').hoverIntent(omFadeIn,omFadeOut); //jquery hoverintent
      $('." . $menu . " li.om-leaf').hoverIntent({
        over: omFadeIn,
        timeout: 500,
        out: omFadeOut
      });
    });
    function omFadeIn(){ $('.om-maximenu-content', this).fadeIn();}
    function omFadeOut(){ $('.om-maximenu-content', this).fadeOut();} 
    ";
  if ($checked == 1) {
    drupal_add_js(drupal_get_path('module', 'om_maximenu') . '/contrib/jquery.hoverIntent.minified.js', 'module'); 
    drupal_add_js($add_js, "inline");
  }
}


